==> igniteui-react-charts-16.6.8.tgz: package/ES2015/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class AverageTrueRangeIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new AverageTrueRangeIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return AverageTrueRangeIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get qq() {
        return typeGetValue(this.c(AverageTrueRangeIndicator.qr));
    }
    set qq(a) {
        this.h(AverageTrueRangeIndicator.qr, a);
    }
    qb() {
        return this.qq;
    }
    qk(a) {
        this.qq = a;
    }
}
AverageTrueRangeIndicator.$t = markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
AverageTrueRangeIndicator.qr = StrategyBasedIndicator.qn(14, AverageTrueRangeIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class AverageTrueRangeIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new AverageTrueRangeIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return AverageTrueRangeIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get qx() {
        return typeGetValue(this.c(AverageTrueRangeIndicator.qy));
    }
    set qx(a) {
        this.h(AverageTrueRangeIndicator.qy, a);
    }
    qi() {
        return this.qx;
    }
    qr(a) {
        this.qx = a;
    }
}
AverageTrueRangeIndicator.$t = markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
AverageTrueRangeIndicator.qy = StrategyBasedIndicator.qu(14, AverageTrueRangeIndicator.$);
